@@ -2,6 +2,7 @@ from minio import Minio
 import os
 import io
 import base64
+from io import BytesIO
 
 class PyMinio:
     def __init__(self, host, port, access_key, secret_key, secure=False):
@@ -103,7 +104,7 @@ class PyMinio:
             image_name = hash_md5.hexdigest() + "." + filetype
             object_name = "{}/{}.{}".format(image_name[:2], image_name[2:], filetype)
 
-        result = self.client.put_object(bucket, object_name, image_data, len(image_data))
+        result = self.client.put_object(bucket, object_name, BytesIO(image_data), len(image_data))
 
         if result!=None:
             return "{}/{}".format(bucket, object_name)
